@@ -334,7 +334,7 @@ public abstract class BaseModel implements ArtifactProvider, Serializable {
   private String getEntryExtension(String entry) throws InvalidFormatException {
     int extensionIndex = entry.lastIndexOf('.') + 1;
 
-    if (extensionIndex == -1 || extensionIndex >= entry.length())
+    if (extensionIndex >= entry.length())
         throw new InvalidFormatException("Entry name must have type extension: " + entry);
 
     return entry.substring(extensionIndex);
